| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vision.Files.AsyncBatchAnnotate
Contents
Description
Run asynchronous image detection and annotation for a list of generic files, such as PDF files, which may contain multiple pages and multiple images per page. Progress and results can be retrieved through the google.longrunning.Operations interface. Operation.metadata contains OperationMetadata (metadata). Operation.response contains AsyncBatchAnnotateFilesResponse (results).
See: Cloud Vision API Reference for vision.files.asyncBatchAnnotate.
Synopsis
- type VisionFilesAsyncBatchAnnotateResource = "v1p2beta1" :> ("files:asyncBatchAnnotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesRequest :> Post '[JSON] Operation))))))))
- data VisionFilesAsyncBatchAnnotate = VisionFilesAsyncBatchAnnotate {}
- newVisionFilesAsyncBatchAnnotate :: GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesRequest -> VisionFilesAsyncBatchAnnotate
Resource
type VisionFilesAsyncBatchAnnotateResource = "v1p2beta1" :> ("files:asyncBatchAnnotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesRequest :> Post '[JSON] Operation)))))))) Source #
A resource alias for vision.files.asyncBatchAnnotate method which the
VisionFilesAsyncBatchAnnotate request conforms to.
Constructing a Request
data VisionFilesAsyncBatchAnnotate Source #
Run asynchronous image detection and annotation for a list of generic files, such as PDF files, which may contain multiple pages and multiple images per page. Progress and results can be retrieved through the google.longrunning.Operations interface. Operation.metadata contains OperationMetadata (metadata). Operation.response contains AsyncBatchAnnotateFilesResponse (results).
See: newVisionFilesAsyncBatchAnnotate smart constructor.
Constructors
| VisionFilesAsyncBatchAnnotate | |
Fields
| |
Instances
newVisionFilesAsyncBatchAnnotate Source #
Arguments
| :: GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesRequest | Multipart request metadata. See |
| -> VisionFilesAsyncBatchAnnotate |
Creates a value of VisionFilesAsyncBatchAnnotate with the minimum fields required to make a request.