| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vision.Images.AsyncBatchAnnotate
Contents
Description
Run asynchronous image detection and annotation for a list of images. Progress and results can be retrieved through the google.longrunning.Operations interface. Operation.metadata contains OperationMetadata (metadata). Operation.response contains AsyncBatchAnnotateImagesResponse (results). This service will write image annotation outputs to json files in customer GCS bucket, each json file containing BatchAnnotateImagesResponse proto.
See: Cloud Vision API Reference for vision.images.asyncBatchAnnotate.
Synopsis
- type VisionImagesAsyncBatchAnnotateResource = "v1p2beta1" :> ("images:asyncBatchAnnotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVisionV1p2beta1AsyncBatchAnnotateImagesRequest :> Post '[JSON] Operation))))))))
- data VisionImagesAsyncBatchAnnotate = VisionImagesAsyncBatchAnnotate {}
- newVisionImagesAsyncBatchAnnotate :: GoogleCloudVisionV1p2beta1AsyncBatchAnnotateImagesRequest -> VisionImagesAsyncBatchAnnotate
Resource
type VisionImagesAsyncBatchAnnotateResource = "v1p2beta1" :> ("images:asyncBatchAnnotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVisionV1p2beta1AsyncBatchAnnotateImagesRequest :> Post '[JSON] Operation)))))))) Source #
A resource alias for vision.images.asyncBatchAnnotate method which the
VisionImagesAsyncBatchAnnotate request conforms to.
Constructing a Request
data VisionImagesAsyncBatchAnnotate Source #
Run asynchronous image detection and annotation for a list of images. Progress and results can be retrieved through the google.longrunning.Operations interface. Operation.metadata contains OperationMetadata (metadata). Operation.response contains AsyncBatchAnnotateImagesResponse (results). This service will write image annotation outputs to json files in customer GCS bucket, each json file containing BatchAnnotateImagesResponse proto.
See: newVisionImagesAsyncBatchAnnotate smart constructor.
Constructors
| VisionImagesAsyncBatchAnnotate | |
Fields
| |
Instances
newVisionImagesAsyncBatchAnnotate Source #
Arguments
| :: GoogleCloudVisionV1p2beta1AsyncBatchAnnotateImagesRequest | Multipart request metadata. See |
| -> VisionImagesAsyncBatchAnnotate |
Creates a value of VisionImagesAsyncBatchAnnotate with the minimum fields required to make a request.