| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vision.Projects.Files.Annotate
Contents
Description
Service that performs image detection and annotation for a batch of files. Now only "application/pdf", "image/tiff" and "image/gif" are supported. This service will extract at most 5 (customers can specify which 5 in AnnotateFileRequest.pages) frames (gif) or pages (pdf or tiff) from each file provided and perform detection and annotation for each image extracted.
See: Cloud Vision API Reference for vision.projects.files.annotate.
Synopsis
- type VisionProjectsFilesAnnotateResource = "v1p2beta1" :> (Capture "parent" Text :> ("files:annotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVisionV1p2beta1BatchAnnotateFilesRequest :> Post '[JSON] GoogleCloudVisionV1p2beta1BatchAnnotateFilesResponse)))))))))
- data VisionProjectsFilesAnnotate = VisionProjectsFilesAnnotate {}
- newVisionProjectsFilesAnnotate :: Text -> GoogleCloudVisionV1p2beta1BatchAnnotateFilesRequest -> VisionProjectsFilesAnnotate
Resource
type VisionProjectsFilesAnnotateResource = "v1p2beta1" :> (Capture "parent" Text :> ("files:annotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVisionV1p2beta1BatchAnnotateFilesRequest :> Post '[JSON] GoogleCloudVisionV1p2beta1BatchAnnotateFilesResponse))))))))) Source #
A resource alias for vision.projects.files.annotate method which the
VisionProjectsFilesAnnotate request conforms to.
Constructing a Request
data VisionProjectsFilesAnnotate Source #
Service that performs image detection and annotation for a batch of files. Now only "application/pdf", "image/tiff" and "image/gif" are supported. This service will extract at most 5 (customers can specify which 5 in AnnotateFileRequest.pages) frames (gif) or pages (pdf or tiff) from each file provided and perform detection and annotation for each image extracted.
See: newVisionProjectsFilesAnnotate smart constructor.
Constructors
| VisionProjectsFilesAnnotate | |
Fields
| |
Instances
newVisionProjectsFilesAnnotate Source #
Arguments
| :: Text | Optional. Target project and location to make a call. Format: |
| -> GoogleCloudVisionV1p2beta1BatchAnnotateFilesRequest | Multipart request metadata. See |
| -> VisionProjectsFilesAnnotate |
Creates a value of VisionProjectsFilesAnnotate with the minimum fields required to make a request.