| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vision.Projects.Files.AsyncBatchAnnotate
Contents
Description
Run asynchronous image detection and annotation for a list of generic files, such as PDF files, which may contain multiple pages and multiple images per page. Progress and results can be retrieved through the google.longrunning.Operations interface. Operation.metadata contains OperationMetadata (metadata). Operation.response contains AsyncBatchAnnotateFilesResponse (results).
See: Cloud Vision API Reference for vision.projects.files.asyncBatchAnnotate.
Synopsis
- type VisionProjectsFilesAsyncBatchAnnotateResource = "v1p2beta1" :> (Capture "parent" Text :> ("files:asyncBatchAnnotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesRequest :> Post '[JSON] Operation)))))))))
- data VisionProjectsFilesAsyncBatchAnnotate = VisionProjectsFilesAsyncBatchAnnotate {}
- newVisionProjectsFilesAsyncBatchAnnotate :: Text -> GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesRequest -> VisionProjectsFilesAsyncBatchAnnotate
Resource
type VisionProjectsFilesAsyncBatchAnnotateResource = "v1p2beta1" :> (Capture "parent" Text :> ("files:asyncBatchAnnotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesRequest :> Post '[JSON] Operation))))))))) Source #
A resource alias for vision.projects.files.asyncBatchAnnotate method which the
VisionProjectsFilesAsyncBatchAnnotate request conforms to.
Constructing a Request
data VisionProjectsFilesAsyncBatchAnnotate Source #
Run asynchronous image detection and annotation for a list of generic files, such as PDF files, which may contain multiple pages and multiple images per page. Progress and results can be retrieved through the google.longrunning.Operations interface. Operation.metadata contains OperationMetadata (metadata). Operation.response contains AsyncBatchAnnotateFilesResponse (results).
See: newVisionProjectsFilesAsyncBatchAnnotate smart constructor.
Constructors
| VisionProjectsFilesAsyncBatchAnnotate | |
Fields
| |
Instances
newVisionProjectsFilesAsyncBatchAnnotate Source #
Arguments
| :: Text | Optional. Target project and location to make a call. Format: |
| -> GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesRequest | Multipart request metadata. See |
| -> VisionProjectsFilesAsyncBatchAnnotate |
Creates a value of VisionProjectsFilesAsyncBatchAnnotate with the minimum fields required to make a request.