| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vision.Projects.Images.AsyncBatchAnnotate
Contents
Description
Run asynchronous image detection and annotation for a list of images. Progress and results can be retrieved through the google.longrunning.Operations interface. Operation.metadata contains OperationMetadata (metadata). Operation.response contains AsyncBatchAnnotateImagesResponse (results). This service will write image annotation outputs to json files in customer GCS bucket, each json file containing BatchAnnotateImagesResponse proto.
See: Cloud Vision API Reference for vision.projects.images.asyncBatchAnnotate.
Synopsis
- type VisionProjectsImagesAsyncBatchAnnotateResource = "v1p2beta1" :> (Capture "parent" Text :> ("images:asyncBatchAnnotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVisionV1p2beta1AsyncBatchAnnotateImagesRequest :> Post '[JSON] Operation)))))))))
- data VisionProjectsImagesAsyncBatchAnnotate = VisionProjectsImagesAsyncBatchAnnotate {}
- newVisionProjectsImagesAsyncBatchAnnotate :: Text -> GoogleCloudVisionV1p2beta1AsyncBatchAnnotateImagesRequest -> VisionProjectsImagesAsyncBatchAnnotate
Resource
type VisionProjectsImagesAsyncBatchAnnotateResource = "v1p2beta1" :> (Capture "parent" Text :> ("images:asyncBatchAnnotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVisionV1p2beta1AsyncBatchAnnotateImagesRequest :> Post '[JSON] Operation))))))))) Source #
A resource alias for vision.projects.images.asyncBatchAnnotate method which the
VisionProjectsImagesAsyncBatchAnnotate request conforms to.
Constructing a Request
data VisionProjectsImagesAsyncBatchAnnotate Source #
Run asynchronous image detection and annotation for a list of images. Progress and results can be retrieved through the google.longrunning.Operations interface. Operation.metadata contains OperationMetadata (metadata). Operation.response contains AsyncBatchAnnotateImagesResponse (results). This service will write image annotation outputs to json files in customer GCS bucket, each json file containing BatchAnnotateImagesResponse proto.
See: newVisionProjectsImagesAsyncBatchAnnotate smart constructor.
Constructors
| VisionProjectsImagesAsyncBatchAnnotate | |
Fields
| |
Instances
newVisionProjectsImagesAsyncBatchAnnotate Source #
Arguments
| :: Text | Optional. Target project and location to make a call. Format: |
| -> GoogleCloudVisionV1p2beta1AsyncBatchAnnotateImagesRequest | Multipart request metadata. See |
| -> VisionProjectsImagesAsyncBatchAnnotate |
Creates a value of VisionProjectsImagesAsyncBatchAnnotate with the minimum fields required to make a request.